@@ -17,7 +17,7 @@
 #include <libsoup/soup.h>
 #include <libecal/e-cal-time-util.h>
 #include <libecal/e-cal.h>
-#include <e-util/e-time-utils.h>
+#include <libedataserver/e-time-utils.h>
 #include "lib/sunone-util.h"
 #include "sunone-invitation-list-model.h"
 #include "sunone-component.h"
